{% load sri %}

{% sri_static 'fleetfinder/libs/DataTables/2.3.4/datatables.min.js' %}
{% sri_static 'fleetfinder/libs/DataTables/2.3.4/dataTables.bootstrap5.min.js' %}

{% if extColumnControl == True %}
    {% sri_static "fleetfinder/libs/DataTables/Extensions/ColumnControl/1.1.1/js/dataTables.columnControl.min.js" %}
    {% sri_static "fleetfinder/libs/DataTables/Extensions/ColumnControl/1.1.1/js/columnControl.bootstrap5.min.js" %}
{% endif %}

{% if extFixedHeader == True %}
    {% sri_static "fleetfinder/libs/DataTables/Extensions/FixedHeader/4.0.4/js/dataTables.fixedHeader.min.js" %}
    {% sri_static "fleetfinder/libs/DataTables/Extensions/FixedHeader/4.0.4/js/fixedHeader.bootstrap5.min.js" %}
{% endif %}
